==> openjdk-13_13.0.7+5.orig.tar.xz: openjdk-13-13.0.7+5/src/hotspot/share/gc/z/zRelocate.hpp <==
/*
 * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#ifndef SHARE_GC_Z_ZRELOCATE_HPP
#define SHARE_GC_Z_ZRELOCATE_HPP

#include "gc/z/zRelocationSet.hpp"
#include "gc/z/zWorkers.hpp"
#include "memory/allocation.hpp"

class ZForwarding;

class ZRelocate {
  friend class ZRelocateTask;

private:
  ZWorkers* const _workers;

  ZForwarding* forwarding_for_page(ZPage* page) const;
  uintptr_t relocate_object_inner(ZForwarding* forwarding, uintptr_t from_index, uintptr_t from_offset) const;
  bool work(ZRelocationSetParallelIterator* iter);

public:
  ZRelocate(ZWorkers* workers);

  uintptr_t relocate_object(ZForwarding* forwarding, uintptr_t from_addr) const;
  uintptr_t forward_object(ZForwarding* forwarding, uintptr_t from_addr) const;

  void start();
  bool relocate(ZRelocationSet* relocation_set);
};

#endif // SHARE_GC_Z_ZRELOCATE_HPP

==> openjdk-16_16.0.1+9.orig.tar.xz: openjdk-16-16.0.1+9/src/hotspot/share/gc/z/zRelocate.hpp <==
/*
 * Copyright (c) 2015, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#ifndef SHARE_GC_Z_ZRELOCATE_HPP
#define SHARE_GC_Z_ZRELOCATE_HPP

#include "gc/z/zRelocationSet.hpp"

class ZForwarding;
class ZWorkers;

class ZRelocate {
  friend class ZRelocateTask;

private:
  ZWorkers* const _workers;

  void work(ZRelocationSetParallelIterator* iter);

public:
  ZRelocate(ZWorkers* workers);

  uintptr_t relocate_object(ZForwarding* forwarding, uintptr_t from_addr) const;
  uintptr_t forward_object(ZForwarding* forwarding, uintptr_t from_addr) const;

  void start();
  void relocate(ZRelocationSet* relocation_set);
};

#endif // SHARE_GC_Z_ZRELOCATE_HPP
